﻿#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
#endregion

namespace SampleGame
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class SampleGame : Microsoft.Xna.Framework.Game
    {
        // グラフィックデバイス管理
        public GraphicsDeviceManager graphics;

        // コンテンツ
        // (ウィザードにて作成されるこのメンバは最初は private ですが、
        // public に変更します)
        public ContentManager content;

        public SampleGame()
        {
            graphics = new GraphicsDeviceManager(this);
            content = new ContentManager(Services);
        }


        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            // TODO: Add your initialization logic here

            // フレームワークの初期化を行います
            if (Global.Initialize(this) != 1)
            {
                // 失敗したらゲームの実行はできませｎ
                Exit();
                return;
            }

            // BGM を鳴らします
            Global.m_soundManager.Play(SoundID.BGM1);

            // プレイヤーを作成します
            PlayerTask player = new PlayerTask();

            // タスク管理に登録します
            Global.m_taskManager.Add(player);

            // エネルギーゲージを作成します
            EnergyGageTask energyGage = new EnergyGageTask();

            // タスク管理に登録します
            Global.m_taskManager.Add(energyGage);

            // ロゴを作成します(右下に置きます)
            LogoTask logo = new LogoTask();
            logo.SetCoordinate(new Point(600, 540));
            Global.m_taskManager.Add(logo);

            base.Initialize();
        }


        /// <summary>
        /// Load your graphics content.  If loadAllContent is true, you should
        /// load content from both ResourceManagementMode pools.  Otherwise, just
        /// load ResourceManagementMode.Manual content.
        /// </summary>
        /// <param name="loadAllContent">Which type of content to load.</param>
        protected override void LoadGraphicsContent(bool loadAllContent)
        {
            if (loadAllContent)
            {
                // TODO: Load any ResourceManagementMode.Automatic content
            }

            // TODO: Load any ResourceManagementMode.Manual content
        }


        /// <summary>
        /// Unload your graphics content.  If unloadAllContent is true, you should
        /// unload content from both ResourceManagementMode pools.  Otherwise, just
        /// unload ResourceManagementMode.Manual content.  Manual content will get
        /// Disposed by the GraphicsDevice during a Reset.
        /// </summary>
        /// <param name="unloadAllContent">Which type of content to unload.</param>
        protected override void UnloadGraphicsContent(bool unloadAllContent)
        {
            if (unloadAllContent)
            {
                // TODO: Unload any ResourceManagementMode.Automatic content
                content.Unload();
            }

            // TODO: Unload any ResourceManagementMode.Manual content
        }


        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            // TODO: Add your update logic here
            // メイン処理を行います
            Global.Execute();

            base.Update(gameTime);
        }


        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            // 背景を黒にします
            graphics.GraphicsDevice.Clear(Color.Black);

            // TODO: Add your drawing code here
            // モデルやスプライトの描画を行います
            DrawManager.Draw(graphics.GraphicsDevice);

            base.Draw(gameTime);
        }
    }
}
